# OpenMNGLab
🚧 under heavy construction, expect every new version to break the API 🚧

[![PyPI](https://img.shields.io/pypi/v/openmnglab?style=for-the-badge)](https://pypi.org/project/openmnglab/) [![PyPI pyversions](https://img.shields.io/pypi/pyversions/openmnglab.svg?style=for-the-badge)](https://pypi.python.org/pypi/pandera/) [![DOCS](https://readthedocs.org/projects/openmnglab/badge/?version=latest&style=for-the-badge)](https://openmnglab.readthedocs.io/en/latest/)


A Python framework for [microneurography](https://en.wikipedia.org/wiki/Microneurography) analysis.
The core idea is to build up an execution plan of pre-defined (implemented) "function modules". The plan can then be executed and 
results retrieved.

## Installation
Currently, the package requires Python v3.11 at minimum.
The package is distributed via PyPI as "[openmnglab](https://pypi.org/project/openmnglab/)". 

## Quickstart
For a quickstart see the [quickstart.ipynb](quickstart/quickstart.ipynb)